<?php
/**
 * @file
 * 
 * This is the main page of the visualization template.
 * 
 * It is responsible for:
 * - setting up the webpage (loading scripts, stylesheets)
 * - setting up the Google Maps API map object
 * - final assembly map content javascripts
 * - UI setup
 * 
 */

//make sure joomla is active
defined('_JEXEC') or die;


/** @var JDocument the webpage itself with relevant Joomla configuration */
$doc = JFactory::getDocument();

//load stylesheets and scripts
$doc->addStyleSheet($this->baseurl . '/templates/' . $this->template . '/css/transdifferenzVis.css');
$doc->addStyleSheet($this->baseurl . '/templates/' . $this->template . '/css/jquery-ui.min.css');
$doc->addStyleSheet($this->baseurl . '/templates/' . $this->template . '/css/jquery-ui.theme.min.css');

$doc->addScript('https://maps.googleapis.com/maps/api/js?key=API_KEY&amp;v=3.exp&amp;language=de-DE&amp;libraries=places', 'text/javascript');
$doc->addScript($this->baseurl . '/templates/' . $this->template . '/js/jquery-ui.min.js', 'text/javascript');
$doc->addScript($this->baseurl . '/templates/' . $this->template . '/js/ui.js', 'text/javascript');

//get migration routes from database
include 'helpers/handler.php';
include 'helpers/routeLoader.php';

?>


<html>
<head>
    
    <meta charset="UTF-8"> 
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <jdoc:include type="head" />
    
    <script>
        
        //setup map
        var MY_MAPTYPE_ID = 'custom_style'; //! @var string the map type
        var center = new google.maps.LatLng(48.20833333,16.371944444); //! @var google.maps.LatLng the center point of the map
                
        function initialize(){
            //configure map look and features
            var featureOpts =
                    [{"featureType": "poi",
                         "stylers": [{"visibility": "off"}]},
                     {"featureType": "transit",
                         "stylers": [{"visibility": "off"}]},
                     {"featureType": "road",
                         "elementType": "labels.icon",
                         "stylers": [{"visibility": "off"}]},
                        {"stylers": [{"saturation": 1},
                                     {"lightness": 20},
                                     {"hue": "#ffb300"},
                                     {"gamma": 0.3}]},
                     {"featureType": "water",
                         "elementType": "geometry",
                         "stylers": [{"lightness": 20},
                                     {"gamma": 1},
                                     {"hue": "#0077ff"},
                                     {"saturation": 1},
                                     {"color": "#9090F0"}]}
                    ];
            // configure map options
            var mapOptions = {
                zoom: 5,
                center: center,
                mapTypeControlOptions: {
                    mapTypeIds: [google.maps.MapTypeId.ROADMAP, MY_MAPTYPE_ID]
                },
                mapTypeId: MY_MAPTYPE_ID,
                disableDefaultUI: true,
                panControl: true,
                panControlOptions: {
                    position: google.maps.ControlPosition.TOP_RIGHT
                },
                zoomControl: true,
                zoomControlOptions: {
                    style: google.maps.ZoomControlStyle.LARGE,
                    position: google.maps.ControlPosition.TOP_RIGHT
                },
                mapTypeControl: false,
                scaleControl: false,
                streetViewControl: false,
                overviewMapControl: false,
                scrollwheel: false
            };
            
            //create map object
            map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

            var styledMapOptions = {
                name: 'Custom Style'
            };

            var customMapType = new google.maps.StyledMapType(featureOpts, styledMapOptions);

            map.mapTypes.set(MY_MAPTYPE_ID, customMapType);
            
            //initialize migration segment array
            var migrationSegments = [];
            
<?php
    //create Google Maps API javascript for migration route segments
    if ($visType === 'all'){
        //all migration routes
        foreach ($migrations as $migration) {
            
            if ($migration['fromLat'] != 999 & $migration['toLat'] != 999){
            echo '
            
            var segment' . $migration['id'] . ' = new google.maps.Polyline({
                path: [{lat:' . $migration['fromLat'] . ',lng:' . $migration['fromLong'] . '},{lat:' . $migration['toLat'] . ',lng:' . $migration['toLong'] . '}],
                strokeColor: \'#ff0000\',
                strokeOpacity: 1.0,
                strokeWeight: 2,
                geodesic: true,
                icons: [{
                    icon: {path: google.maps.SymbolPath.FORWARD_CLOSED_ARROW},
                    offset: \'100%\'
                    }]
                });
            segment' . $migration['id'] . '.setMap(map);
            migrationSegments.push(segment' . $migration['id'] . ');
            ';
            }
        }
    }
    
    else{ 
        //aggregated migration routes
        foreach ($migrations as $migration) {
            
            if ($migration['fromLat'] != 999 && $migration['toLat'] != 999){
                
            $strokeWeight = 1.0 + 10.0 * ( $grid['populations'][$migration['fromPosGrid'][0]][$migration['fromPosGrid'][1]]
                                + $grid['populations'][$migration['toPosGrid'][0]][$migration['toPosGrid'][1]] ) / $maxPopulation;
            
            echo '
            
            var segment' . $migration['id'] . ' = new google.maps.Polyline({
                path: [{lat:' . $grid['centroids'][$migration['fromPosGrid'][0]][$migration['fromPosGrid'][1]][0]
                    . ',lng:' . $grid['centroids'][$migration['fromPosGrid'][0]][$migration['fromPosGrid'][1]][1]
                  . '},{lat:' . $grid['centroids'][$migration['toPosGrid'][0]][$migration['toPosGrid'][1]][0]
                    . ',lng:' . $grid['centroids'][$migration['toPosGrid'][0]][$migration['toPosGrid'][1]][1] . '}],
                strokeColor: \'#ff0000\',
                strokeOpacity: 1.0,
                strokeWeight: '. $strokeWeight .',
                geodesic: true,
                icons: [{
                    icon: {path: google.maps.SymbolPath.FORWARD_CLOSED_ARROW},
                    offset: \'100%\'
                    }]
                });
            segment' . $migration['id'] . '.setMap(map);
            migrationSegments.push(segment' . $migration['id'] . ');
            ';
            }
        }
    }
    
    
?>
            
        }
            
            google.maps.event.addDomListener(window, 'load', initialize);
    </script>
    
</head>
<body>
    <div id="wrapper">
        <div id="maintitle"><a href="/index.php"><img src="/templates/transdifferenz_frontend/images/transdifferenz_logo_hi.png" height="50"></a></div>
        <div id="allMigrationsLoader">Alle Migrationswege</div>
        <div id="aggregatedMigrationsLoader">Aggregierte Migrationswege</div>
        <!--<div id="gridConfigWrapper">
            <p id="gridConfidLabel">Aggregierungsauflösung</p>
            <div id="gridConfigSlider"></div>
            <p id="gridConfigValue">0</p>
            <div class="clear"></div>
        </div>-->
        <div id="map-canvas">
                
        </div>            
    </div>
</body>
</html>